# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'AutomationArtifactStatus',
    'ConfigurationType',
    'LoadBalancerType',
    'OperatingSystemType',
    'ResourceIdentityTypes',
    'SecretStoreType',
    'TargetHydrationStorageProviderType',
    'TargetStorageAccessType',
    'TargetStorageProjectionType',
    'WorkloadDeploymentTarget',
    'WorkloadDeploymentType',
    'WorkloadType',
]


class AutomationArtifactStatus(str, Enum):
    """
    Gets or sets the status of automation artifacts.
    """
    NOT_GENERATED = "NotGenerated"
    GENERATED = "Generated"


class ConfigurationType(str, Enum):
    """
    Gets or sets the configuration type.
    """
    IIS_CONNECTION_STRING = "IISConnectionString"
    IIS_AUTHENTICATION = "IISAuthentication"
    APACHE_TOMCAT_CONTEXT_RESOURCE = "ApacheTomcatContextResource"


class LoadBalancerType(str, Enum):
    """
    Gets or sets the load balancer type.
    """
    PRIVATE = "Private"
    PUBLIC = "Public"


class OperatingSystemType(str, Enum):
    WINDOWS = "Windows"
    LINUX = "Linux"


class ResourceIdentityTypes(str, Enum):
    NONE = "None"
    SYSTEM_ASSIGNED = "SystemAssigned"
    USER_ASSIGNED = "UserAssigned"


class SecretStoreType(str, Enum):
    NONE = "None"
    KUBE_SECRET = "KubeSecret"
    KEY_VAULT_SECRET = "KeyVaultSecret"
    APP_SERVICE_APP_SETTINGS = "AppServiceAppSettings"


class TargetHydrationStorageProviderType(str, Enum):
    """
    Gets or sets the storage provider type on the target.
    Applicable when StorageProjectionType is not ContainerFileSystem.
    """
    AZURE_FILE_SHARE = "AzureFileShare"


class TargetStorageAccessType(str, Enum):
    """
    Gets or sets the target storage access type.
    """
    SHARED = "Shared"
    EXCLUSIVE = "Exclusive"


class TargetStorageProjectionType(str, Enum):
    """
    Gets or sets the target projection type.
    """
    CONTAINER_FILE_SYSTEM = "ContainerFileSystem"
    PERSISTENT_VOLUME = "PersistentVolume"


class WorkloadDeploymentTarget(str, Enum):
    """
    Gets or sets the deployment target platform.
    """
    AZURE_KUBERNETES_SERVICE = "AzureKubernetesService"
    AZURE_APP_SERVICE_CONTAINER = "AzureAppServiceContainer"
    AZURE_APP_SERVICE_NATIVE = "AzureAppServiceNative"


class WorkloadDeploymentType(str, Enum):
    """
    Gets or sets the instance type.
    """
    IISAKS_WORKLOAD_DEPLOYMENT = "IISAKSWorkloadDeployment"
    APACHE_TOMCAT_AKS_WORKLOAD_DEPLOYMENT = "ApacheTomcatAKSWorkloadDeployment"


class WorkloadType(str, Enum):
    """
    Gets or sets the instance type.
    """
    IIS_WORKLOAD = "IISWorkload"
    APACHE_TOMCAT_WORKLOAD = "ApacheTomcatWorkload"
