# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'AssignmentType',
    'Kind',
]


class AssignmentType(str, Enum):
    """
    Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
    """
    AUDIT = "Audit"
    DEPLOY_AND_AUTO_CORRECT = "DeployAndAutoCorrect"
    APPLY_AND_AUTO_CORRECT = "ApplyAndAutoCorrect"
    APPLY_AND_MONITOR = "ApplyAndMonitor"


class Kind(str, Enum):
    """
    Kind of the guest configuration. For example:DSC
    """
    DSC = "DSC"
