# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'SkuName',
]


class SkuName(str, Enum):
    """
    The sku name
    """
    F0 = "F0"
    S1 = "S1"
