# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ManagedIdentityTypes',
    'MonitoringStatus',
    'ProvisioningState',
    'TagAction',
]


class ManagedIdentityTypes(str, Enum):
    """
    Managed identity type.
    """
    SYSTEM_ASSIGNED = "SystemAssigned"


class MonitoringStatus(str, Enum):
    """
    Flag specifying if the resource monitoring is enabled or disabled.
    """
    ENABLED = "Enabled"
    DISABLED = "Disabled"


class ProvisioningState(str, Enum):
    """
    Provisioning state of the monitoring tag rules.
    """
    ACCEPTED = "Accepted"
    CREATING = "Creating"
    UPDATING = "Updating"
    DELETING = "Deleting"
    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"
    DELETED = "Deleted"
    NOT_SPECIFIED = "NotSpecified"


class TagAction(str, Enum):
    """
    Valid actions for a filtering tag.
    """
    INCLUDE = "Include"
    EXCLUDE = "Exclude"
