# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .app_service_certificate_order import *
from .app_service_certificate_order_certificate import *
from .get_app_service_certificate_order import *
from .get_app_service_certificate_order_certificate import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azure_native.certificateregistration.v20150801 as __v20150801
    v20150801 = __v20150801
    import pulumi_azure_native.certificateregistration.v20180201 as __v20180201
    v20180201 = __v20180201
    import pulumi_azure_native.certificateregistration.v20190801 as __v20190801
    v20190801 = __v20190801
    import pulumi_azure_native.certificateregistration.v20200601 as __v20200601
    v20200601 = __v20200601
    import pulumi_azure_native.certificateregistration.v20200901 as __v20200901
    v20200901 = __v20200901
    import pulumi_azure_native.certificateregistration.v20201001 as __v20201001
    v20201001 = __v20201001
    import pulumi_azure_native.certificateregistration.v20201201 as __v20201201
    v20201201 = __v20201201
    import pulumi_azure_native.certificateregistration.v20210101 as __v20210101
    v20210101 = __v20210101
    import pulumi_azure_native.certificateregistration.v20210115 as __v20210115
    v20210115 = __v20210115
    import pulumi_azure_native.certificateregistration.v20210201 as __v20210201
    v20210201 = __v20210201
    import pulumi_azure_native.certificateregistration.v20210301 as __v20210301
    v20210301 = __v20210301
    import pulumi_azure_native.certificateregistration.v20220301 as __v20220301
    v20220301 = __v20220301
    import pulumi_azure_native.certificateregistration.v20220901 as __v20220901
    v20220901 = __v20220901
else:
    v20150801 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20150801')
    v20180201 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20180201')
    v20190801 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20190801')
    v20200601 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20200601')
    v20200901 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20200901')
    v20201001 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20201001')
    v20201201 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20201201')
    v20210101 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20210101')
    v20210115 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20210115')
    v20210201 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20210201')
    v20210301 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20210301')
    v20220301 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20220301')
    v20220901 = _utilities.lazy_import('pulumi_azure_native.certificateregistration.v20220901')

