# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'BindingType',
    'HTTPSchemeType',
    'ManagedIdentityType',
    'ProbeActionType',
    'StorageType',
    'Type',
]


class BindingType(str, Enum):
    """
    Buildpack Binding Type
    """
    APPLICATION_INSIGHTS = "ApplicationInsights"
    APACHE_SKY_WALKING = "ApacheSkyWalking"
    APP_DYNAMICS = "AppDynamics"
    DYNATRACE = "Dynatrace"
    NEW_RELIC = "NewRelic"
    ELASTIC_APM = "ElasticAPM"


class HTTPSchemeType(str, Enum):
    """
    Scheme to use for connecting to the host. Defaults to HTTP.

    Possible enum values:
     - `"HTTP"` means that the scheme used will be http://
     - `"HTTPS"` means that the scheme used will be https://
    """
    HTTP = "HTTP"
    HTTPS = "HTTPS"


class ManagedIdentityType(str, Enum):
    """
    Type of the managed identity
    """
    NONE = "None"
    SYSTEM_ASSIGNED = "SystemAssigned"
    USER_ASSIGNED = "UserAssigned"
    SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned,UserAssigned"


class ProbeActionType(str, Enum):
    """
    The type of the action to take to perform the health check.
    """
    HTTP_GET_ACTION = "HTTPGetAction"
    TCP_SOCKET_ACTION = "TCPSocketAction"
    EXEC_ACTION = "ExecAction"


class StorageType(str, Enum):
    """
    The type of the storage.
    """
    STORAGE_ACCOUNT = "StorageAccount"


class Type(str, Enum):
    """
    The type of the underlying resource to mount as a persistent disk.
    """
    AZURE_FILE_VOLUME = "AzureFileVolume"
